package com.aucma.report.service;

import java.util.List;
import java.util.Map;

import com.aucma.report.domain.EnergyStatisticalReport;
import com.aucma.report.domain.ProductTraceabilityReport;
import com.aucma.report.domain.ReportDayDnb;

/**
 * 电日耗报Service接口
 * 
 * @author ruoyi
 * @date 2023-10-09
 */
public interface IReportDayDnbService 
{
    /**
     * 查询电日耗报
     * 
     * @param objId 电日耗报主键
     * @return 电日耗报
     */
    public ReportDayDnb selectReportDayDnbByObjId(Long objId);

    /**
     * 查询电日耗报列表
     * 
     * @param reportDayDnb 电日耗报
     * @return 电日耗报集合
     */
    public List<ReportDayDnb> selectReportDayDnbList(ReportDayDnb reportDayDnb);

    /**
     * 新增电日耗报
     * 
     * @param reportDayDnb 电日耗报
     * @return 结果
     */
    public int insertReportDayDnb(ReportDayDnb reportDayDnb);

    /**
     * 修改电日耗报
     * 
     * @param reportDayDnb 电日耗报
     * @return 结果
     */
    public int updateReportDayDnb(ReportDayDnb reportDayDnb);

    /**
     * 批量删除电日耗报
     * 
     * @param objIds 需要删除的电日耗报主键集合
     * @return 结果
     */
    public int deleteReportDayDnbByObjIds(Long[] objIds);

    /**
     * 删除电日耗报信息
     * 
     * @param objId 电日耗报主键
     * @return 结果
     */
    public int deleteReportDayDnbByObjId(Long objId);

    /**
     * 统计能耗报表
     * @param hashMap
     * @return
     */
    List<EnergyStatisticalReport> energyStatisticalReportList(Map hashMap);
}
